Deposit bundle (alpha)
----------------------

.. note::

    This bundle is in alpha. The modules are being used in production systems
    but are very likely subject to change.

.. warning::

    All modules on this page will be discontinued, as they are some significant
    design issues in them.

Included modules:

- `invenio-deposit <https://invenio-deposit.readthedocs.io>`_
    - REST API for managing deposit of records into Invenio with support for
      in progress editing of records.
- `invenio-files-js <https://www.npmjs.com/package/invenio-files-js>`_
    - AngularJS application for uploading files to Invenio via streaming the
      binary files in an HTTP request.
- `invenio-records-js <https://invenio-records-js.readthedocs.io>`_
    - AngularJS application for interacting with the deposit REST API and
      rendering forms based on angular schema forms.
- `invenio-sipstore <https://invenio-sipstore.readthedocs.io>`_
    - Submission Information Package (SIP) store with bagit support.
